@@ -20,8 +20,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <gnome.h>
-
 #include "seahorse-prefs.h"
 #include "seahorse-gconf.h"
 #include "seahorse-preferences.h"
@@ -35,9 +33,9 @@
  * Creates a new or shows the current preferences dialog.
  **/
 void
-seahorse_preferences_show (const gchar *tabid)
+seahorse_preferences_show (GtkWindow *parent, const gchar *tabid)
 {   
-    SeahorseWidget *swidget = seahorse_prefs_new ();
+    SeahorseWidget *swidget = seahorse_prefs_new (parent);
     GtkWidget *tab;
     
     if (tabid) {
